California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 21 - 2000 JUVENILE CRIME. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
980133 | CALIFORNIANS TO END GANG VIOLENCE, YES ON PROP. 21 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
991529 | CALIFORNIANS FOR COMMUNITY SAFETY - NO ON 21 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
992431 | AMERICAN FRIENDS SERVICE COMMITTEE AGAINST PROP. 21 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1221968 | CALIFORNIANS FOR COMMUNITY SAFETY- COMMITTEE AGAINST PROPOSITION 21 | OPPOSE